@@ -7,7 +7,7 @@
 #' @param alpha_fill The opacity of the fill. Defaults to 0.2. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param alpha_point The opacity of the outlier points. Defaults to 1.  
-#' @param size_point The size of the outlier points. Defaults to 1.
+#' @param size_point The size of the outlier points. Defaults to 1.5.
 #' @param size_line The size of the outlines of boxplots. Defaults to 0.5.
 #' @param size_width Width of boxes. Defaults to 0.5.
 #' @param title Title string. 
@@ -79,7 +79,7 @@ gg_boxplot <- function(data,
                        alpha_line = 1,
                        alpha_point = 1,
                        size_line = 0.5,
-                       size_point = 1,
+                       size_point = 1.5,
                        size_width = 0.5,
                        title = NULL,
                        title_wrap = 80,
@@ -107,7 +107,7 @@ gg_boxplot <- function(data,
                        ymiddle_var = NULL,
                        yupper_var = NULL,
                        ymax_var = NULL,
-                       theme = gg_theme(),
+                       theme = gg_theme(gridlines_h = TRUE),
                        mobile = FALSE) {
   
   #ungroup
@@ -139,7 +139,7 @@ gg_boxplot <- function(data,
   }
   
   #warnings
-  if (is.numeric(x_var_vctr)) stop("Please use a numeric x variable for a boxplot")
+    if (is.numeric(x_var_vctr)) stop("Please use a categorical x variable for a boxplot")
   if (stat == "boxplot" & !is.numeric(y_var_vctr)) stop("Please use a numeric y variable for a boxplot when stat = 'boxplot'")
   
   #logical to factor
@@ -278,7 +278,7 @@ gg_boxplot <- function(data,
 #' @param alpha_fill The opacity of the fill. Defaults to 0.2. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param alpha_point The opacity of the outlier points. Defaults to 1.  
-#' @param size_point The size of the outlier points. Defaults to 1.
+#' @param size_point The size of the outlier points. Defaults to 1.5.
 #' @param size_line The size of the outlines of boxplots. Defaults to 0.5.
 #' @param size_width Width of boxes. Defaults to 0.5.
 #' @param title Title string. 
@@ -371,7 +371,7 @@ gg_boxplot_col <- function(data,
                            alpha_line = 1,
                            alpha_point = 1,
                            size_line = 0.5,
-                           size_point = 1,
+                           size_point = 1.5,
                            size_width = 0.5,
                            title = NULL,
                            title_wrap = 80,
@@ -399,7 +399,7 @@ gg_boxplot_col <- function(data,
                            col_title_wrap = 25,
                            caption = NULL,
                            caption_wrap = 80,
-                           theme = gg_theme(),
+                           theme = gg_theme(gridlines_h = TRUE),
                            stat = "boxplot",
                            ymin_var = NULL,
                            ylower_var = NULL,
@@ -444,7 +444,7 @@ gg_boxplot_col <- function(data,
   }
   
   #warnings
-  if (is.numeric(x_var_vctr)) stop("Please use a numeric x variable for a boxplot")
+    if (is.numeric(x_var_vctr)) stop("Please use a categorical x variable for a boxplot")
   if (stat == "boxplot" & !is.numeric(y_var_vctr)) stop("Please use a numeric y variable for a boxplot when stat = 'boxplot'")
   if (is.numeric(col_var_vctr)) stop("Please use a categorical colour variable for a boxplot")
   
@@ -632,7 +632,7 @@ gg_boxplot_col <- function(data,
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param alpha_point The opacity of the outlier points. Defaults to 1.  
 #' @param size_line The size of the outlines of boxplots. Defaults to 0.5.
-#' @param size_point The size of the outlier points. Defaults to 1.
+#' @param size_point The size of the outlier points. Defaults to 1.5.
 #' @param size_width Width of boxes. Defaults to 0.5.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
@@ -689,7 +689,7 @@ gg_boxplot_facet <- function(data,
                              alpha_line = 1,
                              alpha_point = 1,
                              size_line = 0.5,
-                             size_point = 1,
+                             size_point = 1.5,
                              size_width = 0.5,
                              title = NULL,
                              title_wrap = 80,
@@ -717,7 +717,7 @@ gg_boxplot_facet <- function(data,
                              facet_scales = "fixed",
                              caption = NULL,
                              caption_wrap = 80,
-                             theme = gg_theme(), 
+                             theme = gg_theme(gridlines_h = TRUE), 
                              stat = "boxplot",
                              ymin_var = NULL,
                              ylower_var = NULL,
@@ -761,7 +761,7 @@ gg_boxplot_facet <- function(data,
   }
   
   #warnings
-  if (is.numeric(x_var_vctr)) stop("Please use a numeric x variable for a boxplot")
+    if (is.numeric(x_var_vctr)) stop("Please use a categorical x variable for a boxplot")
   if (stat == "boxplot" & !is.numeric(y_var_vctr)) stop("Please use a numeric y variable for a boxplot when stat = 'boxplot'")
   if (is.numeric(facet_var_vctr)) stop("Please use a categorical facet variable for a boxplot")
   
@@ -909,7 +909,7 @@ gg_boxplot_facet <- function(data,
 #' @param alpha_fill The opacity of the fill. Defaults to 0.2. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param alpha_point The opacity of the outlier points. Defaults to 1.  
-#' @param size_point The size of the outlier points. Defaults to 1.
+#' @param size_point The size of the outlier points. Defaults to 1.5.
 #' @param size_line The size of the outlines of boxplots. Defaults to 0.5.
 #' @param size_width Width of boxes. Defaults to 0.5.
 #' @param title Title string. 
@@ -982,7 +982,7 @@ gg_boxplot_col_facet <- function(data,
                                  alpha_line = 1,
                                  alpha_point = 1,
                                  size_line = 0.5,
-                                 size_point = 1,
+                                 size_point = 1.5,
                                  size_width = 0.5,
                                  title = NULL,
                                  title_wrap = 80,
@@ -1016,7 +1016,7 @@ gg_boxplot_col_facet <- function(data,
                                  facet_scales = "fixed",
                                  caption = NULL,
                                  caption_wrap = 80,
-                                 theme = gg_theme(), 
+                                 theme = gg_theme(gridlines_h = TRUE), 
                                  stat = "boxplot",
                                  ymin_var = NULL,
                                  ylower_var = NULL,
@@ -1067,7 +1067,7 @@ gg_boxplot_col_facet <- function(data,
   }
   
   #warnings
-  if (is.numeric(x_var_vctr)) stop("Please use a numeric x variable for a boxplot")
+    if (is.numeric(x_var_vctr)) stop("Please use a categorical x variable for a boxplot")
   if (stat == "boxplot" & !is.numeric(y_var_vctr)) stop("Please use a numeric y variable for a boxplot when stat = 'boxplot'")
   if (is.numeric(col_var_vctr)) stop("Please use a categorical colour variable for a boxplot")
   if (is.numeric(facet_var_vctr)) stop("Please use a categorical facet variable for a boxplot")
