@@ -68,7 +68,7 @@ gg_density <- function(data,
                        y_title_wrap = 50,
                        caption = NULL,
                        caption_wrap = 80,
-                       theme = gg_theme(),
+                       theme = gg_theme(gridlines_h = TRUE, gridlines_v = TRUE),
                        model_bw = "nrd0",
                        model_adjust = 1,
                        model_kernel = "gaussian",
@@ -255,7 +255,7 @@ gg_density_col <- function(data,
                            col_title_wrap = 25,
                            caption = NULL,
                            caption_wrap = 80,
-                           theme = gg_theme(),
+                           theme = gg_theme(gridlines_h = TRUE, gridlines_v = TRUE),
                            model_bw = "nrd0",
                            model_adjust = 1,
                            model_kernel = "gaussian",
@@ -495,7 +495,7 @@ gg_density_facet <- function(data,
                              facet_scales = "fixed",
                              caption = NULL,
                              caption_wrap = 80,
-                             theme = gg_theme(), 
+                             theme = gg_theme(gridlines_h = TRUE, gridlines_v = TRUE), 
                              model_bw = "nrd0",
                              model_adjust = 1,
                              model_kernel = "gaussian",
@@ -706,7 +706,7 @@ gg_density_col_facet <- function(data,
                                  facet_scales = "fixed",
                                  caption = NULL,
                                  caption_wrap = 80, 
-                                 theme = gg_theme(), 
+                                 theme = gg_theme(gridlines_h = TRUE, gridlines_v = TRUE), 
                                  model_bw = "nrd0",
                                  model_adjust = 1,
                                  model_kernel = "gaussian",
