@@ -88,7 +88,7 @@ gg_hbar <- function(data,
                     y_zero_line = NULL,
                     caption = NULL,
                     caption_wrap = 75,
-                    theme = gg_theme(gridlines = "vertical"),
+                    theme = gg_theme(gridlines_v = TRUE),
                     mobile = FALSE) {
   
   #ungroup
@@ -392,7 +392,7 @@ gg_hbar_col <- function(data,
                         col_title_wrap = 25,
                         caption = NULL,
                         caption_wrap = 75,
-                        theme = gg_theme(gridlines = "vertical"),
+                        theme = gg_theme(gridlines_v = TRUE),
                         mobile = FALSE) {
   
   #ungroup
@@ -823,7 +823,7 @@ gg_hbar_facet <- function(data,
                           facet_scales = "fixed",
                           caption = NULL,
                           caption_wrap = 75,
-                          theme = gg_theme(gridlines = "vertical")) {
+                          theme = gg_theme(gridlines_v = TRUE)) {
   
   #ungroup
   data <- dplyr::ungroup(data)
@@ -1130,7 +1130,7 @@ gg_hbar_col_facet <- function(data,
                               facet_scales = "fixed",
                               caption = NULL,
                               caption_wrap = 75,
-                              theme = gg_theme(gridlines = "vertical")) {
+                              theme = gg_theme(gridlines_v = TRUE)) {
   
   #ungroup
   data <- dplyr::ungroup(data)
