@@ -96,7 +96,7 @@ gg_pointrange <- function(data,
                     y_zero_line = NULL,
                     caption = NULL,
                     caption_wrap = 80,
-                    theme = gg_theme(),
+                    theme = gg_theme(gridlines_h = TRUE),
                     mobile = FALSE) {
   
   #ungroup
@@ -374,7 +374,7 @@ gg_pointrange_col <- function(data,
                         col_title_wrap = 25,
                         caption = NULL,
                         caption_wrap = 80,
-                        theme = gg_theme(),
+                        theme = gg_theme(gridlines_h = TRUE),
                         mobile = FALSE) {
   
   #ungroup
@@ -697,7 +697,7 @@ gg_pointrange_facet <- function(data,
                           facet_scales = "fixed",
                           caption = NULL,
                           caption_wrap = 80,
-                          theme = gg_theme()) {
+                          theme = gg_theme(gridlines_h = TRUE)) {
   
   #ungroup
   data <- dplyr::ungroup(data)
@@ -1000,7 +1000,7 @@ gg_pointrange_col_facet <- function(data,
                               facet_scales = "fixed",
                               caption = NULL,
                               caption_wrap = 80,
-                              theme = gg_theme()) {
+                              theme = gg_theme(gridlines_h = TRUE)) {
   
   #ungroup
   data <- dplyr::ungroup(data)
