@@ -41,7 +41,7 @@ gg_stars <- function(data,
                      subtitle_wrap = 80,
                      caption = NULL,
                      caption_wrap = 80,
-                     theme = NULL,
+                     theme = gg_theme(void = TRUE),
                      mobile = FALSE) {
   
   #warnings
@@ -54,8 +54,6 @@ gg_stars <- function(data,
   }
   
   #fundamentals
-  if (is.null(theme)) theme <- gg_theme_map()
-  
   plot <- ggplot() +
     theme +
     scale_x_continuous(expand = c(0, 0), name = NULL) +
@@ -121,7 +119,7 @@ gg_stars <- function(data,
         subtitle = stringr::str_wrap(subtitle, 40),
         caption = stringr::str_wrap(caption, 50)
       ) + 
-      theme_mobile_extra_map()
+      theme_mobile_extra(void = TRUE)
   }
   
   return(plot)
@@ -196,7 +194,7 @@ gg_stars_col <- function(data,
                          col_title_wrap = 25,
                          caption = NULL,
                          caption_wrap = 80,
-                         theme = NULL,
+                         theme = gg_theme(void = TRUE),
                          mobile = FALSE) {
   
   #quote
@@ -236,8 +234,6 @@ gg_stars_col <- function(data,
   if (is.null(col_title)) col_title <- snakecase::to_sentence_case(rlang::as_name(col_var))
   
   #fundamentals
-  if (is.null(theme)) theme <- gg_theme_map()
-  
   plot <- ggplot() +
     theme +
     scale_x_continuous(expand = c(0, 0), name = NULL) +
@@ -405,7 +401,7 @@ gg_stars_col <- function(data,
         subtitle = stringr::str_wrap(subtitle, 40),
         caption = stringr::str_wrap(caption, 50)
       )  +
-      theme_mobile_extra_map()
+      theme_mobile_extra(void = TRUE)
   }
   
   return(plot)
