@@ -105,7 +105,7 @@ gg_tile_col <- function(data,
                         col_title_wrap = 25,
                         caption = NULL,
                         caption_wrap = 75,
-                        theme = gg_theme(gridlines = "none"),
+                        theme = gg_theme(),
                         mobile = FALSE) {
   
   #ungroup
@@ -465,7 +465,7 @@ gg_tile_col_facet <- function(data,
                               facet_scales = "fixed",
                               caption = NULL,
                               caption_wrap = 75,
-                              theme = gg_theme(gridlines = "none"))
+                              theme = gg_theme())
 {
   
   #ungroup
