@@ -13,20 +13,31 @@ library(dplyr)
 library(simplevis)
 library(palmerpenguins)
 library(ggplot2)
+library(patchwork)
+set.seed(123456789)
+
+## -----------------------------------------------------------------------------
+gg_point(penguins,
+         x_var = bill_length_mm,
+         y_var = body_mass_g)
 
 ## -----------------------------------------------------------------------------
 plot_data <- storms %>%
   group_by(year) %>%
   summarise(wind = mean(wind))
 
-gg_bar(plot_data, 
-       x_var = year, 
+gg_bar(plot_data,
+       x_var = year,
        y_var = wind)
 
 ## -----------------------------------------------------------------------------
-gg_point(iris, 
-         x_var = Sepal.Width, 
-         y_var = Sepal.Length)
+plot_data <- storms %>%
+  group_by(year) %>%
+  summarise(wind = mean(wind))
+
+gg_hbar(plot_data, 
+        x_var = wind, 
+        y_var = year)
 
 ## -----------------------------------------------------------------------------
 plot_data <- storms %>%
@@ -38,13 +49,33 @@ gg_line(plot_data,
         y_var = wind)
 
 ## -----------------------------------------------------------------------------
-plot_data <- ggplot2::diamonds %>%
-  group_by(cut) %>%
-  summarise(price = mean(price))
+gg_boxplot(penguins, 
+           x_var = species, 
+           y_var = body_mass_g)
 
-gg_hbar(plot_data, 
-        x_var = price, 
-        y_var = cut)
+## -----------------------------------------------------------------------------
+gg_density(penguins, 
+           x_var = body_mass_g)
+
+## -----------------------------------------------------------------------------
+plot_data <- penguins %>%
+   group_by(sex) %>%
+   summarise(middle = median(body_mass_g, na.rm = TRUE),
+             lower = quantile(body_mass_g, probs = 0.25, na.rm = TRUE),
+             upper = quantile(body_mass_g, probs = 0.75, na.rm = TRUE))
+
+ gg_pointrange(
+   plot_data,
+   x_var = sex,
+   y_var = middle,
+   ymin_var = lower,
+   ymax_var = upper,
+   y_title = "Body mass g")
+
+## -----------------------------------------------------------------------------
+gg_smooth(penguins,  
+          x_var = bill_length_mm, 
+          y_var = body_mass_g)
 
 ## -----------------------------------------------------------------------------
 plot_data <- penguins %>% 
@@ -58,26 +89,20 @@ gg_tile_col(plot_data,
             label_var = bill_length_mm) 
 
 ## -----------------------------------------------------------------------------
-gg_boxplot(storms, 
-           x_var = year, 
-           y_var = wind)
+gg_violin(penguins, 
+           x_var = species, 
+           y_var = body_mass_g)
 
 ## -----------------------------------------------------------------------------
-gg_density(penguins, 
-           x_var = body_mass_g)
-
-## -----------------------------------------------------------------------------
-gg_sf_col(example_sf_point, 
+gg_sf_col(example_point, 
           col_var = trend_category, 
-          borders = nz)
+          borders = example_borders)
 
 ## -----------------------------------------------------------------------------
-library(stars)
-
 gg_stars_col(example_stars,
              col_var = nitrate,
              col_na_rm = TRUE,
-             borders = nz)
+             borders = example_borders)
 
 ## -----------------------------------------------------------------------------
 gg_point(penguins, 
@@ -126,6 +151,13 @@ gg_point(iris,
          y_var = Sepal.Length, 
          pal = "#e7298a")
 
+## -----------------------------------------------------------------------------
+gg_point_col(penguins, 
+             x_var = bill_length_mm, 
+             y_var = body_mass_g, 
+             col_var = species, 
+             pal = c("#da3490", "#9089fa", "#47e26f"))
+
 ## -----------------------------------------------------------------------------
 plot_data <- storms %>%
   group_by(year, status) %>%
@@ -135,13 +167,13 @@ gg_bar_col(plot_data,
         x_var = year, 
         y_var = wind, 
         col_var = status,
-        position = "stack",
-        x_pretty_n = 4,
+        stack = TRUE,
+        x_breaks_n = 4,
         x_labels = function(x) stringr::str_sub(x, 3, 4),
-        y_labels = function(x) scales::comma(x, accuracy = 0.1), 
+        y_labels = scales::label_comma(accuracy = 0.1), 
+        col_labels = c("H", "TD", "TS"),
         y_zero = T, 
-        y_pretty_n = 10,
-        y_gridlines_minor = T,
+        y_breaks_n = 10,
         y_expand = ggplot2::expansion(mult = c(0.025, 0.025)))
 
 ## -----------------------------------------------------------------------------
@@ -153,21 +185,36 @@ gg_point_col(penguins,
 
 ## -----------------------------------------------------------------------------
 plot_data <- penguins %>% 
-  group_by(sex, species) %>% 
-  summarise(count = n())
+  group_by(species) %>% 
+  summarise(body_mass_g = mean(body_mass_g, na.rm = TRUE))  
 
-gg_hbar_col(plot_data, 
-        x_var = count, 
-        y_var = species, 
-        col_var = sex,
-        position = "stack")
+gg_bar_col(plot_data, 
+       x_var = species, 
+       y_var = body_mass_g, 
+       col_var = species, 
+       col_legend_none = TRUE,
+       size_width = 0.5)
 
 ## -----------------------------------------------------------------------------
-gg_sf_col(example_sf_point, 
-          col_var = median, 
-          col_method = "quantile",
-          col_cuts = c(0, 0.25, 0.5, 0.75, 1),
-          borders = nz)
+gg_point_col(penguins, 
+             x_var = bill_length_mm, 
+             y_var = body_mass_g, 
+             col_var = species, 
+             title = "A nice long title", 
+             subtitle = "And a subtitle",
+             theme = ggplot2::theme_grey())
+
+## -----------------------------------------------------------------------------
+gg_sf_col(example_polygon, 
+          col_var = density, 
+          col_method = "continuous",
+          borders = example_borders)
+
+## -----------------------------------------------------------------------------
+gg_sf_col(example_polygon, 
+          col_var = density, 
+          col_method = "bin",
+          borders = example_borders)
 
 ## -----------------------------------------------------------------------------
 gg_stars_col(example_stars,
@@ -175,48 +222,47 @@ gg_stars_col(example_stars,
              col_method = "quantile",
              col_cuts = c(0, 0.05, 0.25, 0.5, 0.75, 0.95, 1),
              col_na_rm = TRUE,
-             borders = nz)
-
-## -----------------------------------------------------------------------------
-leaflet_sf_col(example_sf_point, 
-               col_var = trend_category)
-
-## -----------------------------------------------------------------------------
-library(stars)
-
-leaflet_stars_col(example_stars, 
-                  col_var = nitrate, 
-                  col_method = "quantile", 
-                  col_cuts = c(0, 0.05, 0.25, 0.5, 0.75, 0.95, 1),
-                  col_na_rm = TRUE)
-
+             borders = example_borders)
 
 ## ---- echo = FALSE, message = FALSE, warning = FALSE, fig.width = 7-----------
 tibble::tribble(
-  ~family, ~data, ~x_var, ~y_var, ~col_var, ~facet_var, ~stat,
-  "bar", "tibble or data.frame", "Any*", "Numeric", "Categorical or numeric", "Categorical", "identity",
-  "hbar", "tibble or data.frame", "Numeric", "Any*", "Categorical or numeric", "Categorical", "identity",
-  "line", "tibble or data.frame", "Any", "Numeric", "Categorical", "Categorical", "identity",
-  "point", "tibble or data.frame", "Any", "Numeric", "Categorical or numeric", "Categorical", "identity",
-  "density", "tibble or data.frame", "Numeric", NA, "Categorical",  "Categorical", "density",
-  "boxplot", "tibble or data.frame", "Any*", "Numeric", "Categorical", "Categorical", "boxplot (or identity)",
-  "tile",  "tibble or data.frame", "Categorical", "Categorical", "Categorical or numeric", "Categorical", "identity",
-  "sf", "sf", NA, NA, "Categorical or numeric", "Categorical", "identity",
-  "stars", "stars", NA, NA, "Categorical or numeric", NA, "identity",
-  ) %>% 
-  DT::datatable()
+  ~family, ~data, ~x_var, ~y_var, ~col_var, ~facet_var, 
+  "bar", "tibble or data.frame", "Any*", "Numeric", "Categorical or numeric", "Categorical",
+  "boxplot", "tibble or data.frame", "Categorical", "Numeric", "Categorical", "Categorical",
+  "density", "tibble or data.frame", "Numeric", NA, "Categorical",  "Categorical", 
+  "line", "tibble or data.frame", "Any", "Numeric", "Categorical", "Categorical",
+  "point", "tibble or data.frame", "Any", "Numeric", "Categorical or numeric", "Categorical",
+  "pointrange", "tibble or data.frame", "Any", "Numeric", "Categorical or numeric", "Categorical",
+  "sf", "sf", NA, NA, "Categorical or numeric", "Categorical",
+  "smooth", "tibble or data.frame", "Numeric", "Numeric", "Categorical or numeric", "Categorical",
+  "stars", "stars", NA, NA, "Categorical or numeric", NA,
+  "tile",  "tibble or data.frame", "Categorical", "Categorical", "Categorical or numeric", "Categorical",
+  "violin", "tibble or data.frame", "Categorical", "Numeric", "Categorical", "Categorical", 
+  "hbar", "tibble or data.frame", "Numeric", "Any*", "Categorical or numeric", "Categorical",
+  "hboxplot", "tibble or data.frame", "Numeric", "Categorical", "Categorical", "Categorical",
+  "hviolin", "tibble or data.frame", "Numeric", "Categorical", "Categorical", "Categorical", 
+  "hpointrange", "tibble or data.frame", "Numeric", "Any", "Categorical or numeric", "Categorical"
+  ) %>%
+  DT::datatable(options = list(pageLength = 20, lengthChange = FALSE))
+    
 
 ## -----------------------------------------------------------------------------
 penguins %>% 
   gg_density_col(x_var = body_mass_g, 
-                 col_var = species)
+                 col_var = sex,
+                 col_na_rm = TRUE)
 
 ## -----------------------------------------------------------------------------
-gg_point_col(penguins, 
-             x_var = bill_length_mm, 
-             y_var = body_mass_g, 
+gg_point_col(penguins,
+             x_var = bill_length_mm,
+             y_var = body_mass_g,
              col_var = species) +
-  geom_smooth(aes(x = bill_length_mm, y = body_mass_g, col = species))
+  ggplot2::scale_y_log10(
+    name = "Bill length mm",
+    breaks = function(x) pretty(x, 4),
+    limits = function(x) c(min(pretty(x, 4)), max(pretty(x, 4))),
+    expand = c(0, 0)
+  ) 
 
 
 ## ---- fig.height = 4.5--------------------------------------------------------
@@ -227,22 +273,28 @@ plot_data <- penguins %>%
 gg_bar(plot_data, 
        x_var = sex, 
        y_var = body_mass_g, 
-       width = 0.66, 
+       size_width = 0.66, 
        x_na_rm = TRUE, 
-       y_pretty_n = 3) +
+       y_breaks_n = 3) +
   facet_grid(rows = vars(species), 
              cols = vars(island), 
              labeller = as_labeller(snakecase::to_sentence_case))
 
 
-## ---- eval = FALSE------------------------------------------------------------
-#  plot <- gg_point_col(penguins,
-#                       x_var = bill_length_mm,
-#                       y_var = body_mass_g,
-#                       col_var = species)
-#  
-#  plotly::ggplotly(plot) %>%
-#    plotly_camera()
+## -----------------------------------------------------------------------------
+library(patchwork)
+
+p1 <- gg_point(penguins, 
+               x_var = species, 
+               y_var = body_mass_g, 
+               x_jitter = 0.2, 
+               alpha_point = 0.5) 
+
+p2 <- gg_boxplot(penguins, 
+                 x_var = species, 
+                 y_var = body_mass_g) 
+
+p1 + p2
 
 ## ---- eval = FALSE------------------------------------------------------------
 #  plot <- gg_point_col(penguins,
@@ -252,17 +304,4 @@ gg_bar(plot_data,
 #  
 #  plotly::ggplotly(plot) %>%
 #    plotly_camera()
-#  
-#  plot_data <- penguins %>%
-#    mutate_text()
-#  
-#  plot <- gg_point_col(plot_data,
-#                       x_var = bill_length_mm,
-#                       y_var = body_mass_g,
-#                       col_var = species,
-#                       text_var = text,
-#                       font_family = "Helvetica")
-#  
-#  plotly::ggplotly(plot, tooltip = "text") %>%
-#    plotly_camera()
 
